@@ -3,8 +3,6 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from __future__ import absolute_import
-
 import json
 import sys
 from subprocess import Popen, PIPE
@@ -13,7 +11,7 @@ import warnings
 from IPython.core.profiledir import ProfileDir
 from IPython.paths import get_ipython_dir
 from ipython_genutils.path import filefind
-from ipython_genutils.py3compat import str_to_bytes, PY3
+from ipython_genutils.py3compat import str_to_bytes
 
 import jupyter_client
 from jupyter_client import write_connection_file
@@ -40,7 +38,7 @@ def get_connection_file(app=None):
 def find_connection_file(filename='kernel-*.json', profile=None):
     """DEPRECATED: find a connection file, and return its absolute path.
     
-    THIS FUNCTION IS DEPRECATED. Use juptyer_client.find_connection_file instead.
+    THIS FUNCTION IS DEPRECATED. Use jupyter_client.find_connection_file instead.
 
     Parameters
     ----------
@@ -170,10 +168,9 @@ def connect_qtconsole(connection_file=None, argv=None, profile=None):
     ])
 
     kwargs = {}
-    if PY3:
-        # Launch the Qt console in a separate session & process group, so
-        # interrupting the kernel doesn't kill it. This kwarg is not on Py2.
-        kwargs['start_new_session'] = True
+    # Launch the Qt console in a separate session & process group, so
+    # interrupting the kernel doesn't kill it.
+    kwargs['start_new_session'] = True
 
     return Popen([sys.executable, '-c', cmd, '--existing', cf] + argv,
         stdout=PIPE, stderr=PIPE, close_fds=(sys.platform != 'win32'),
