@@ -3,12 +3,11 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from __future__ import print_function
-
 import errno
 import json
 import os
 import shutil
+import stat
 import sys
 import tempfile
 
@@ -22,7 +21,7 @@ KERNEL_NAME = 'python%i' % sys.version_info[0]
 RESOURCES = pjoin(os.path.dirname(__file__), 'resources')
 
 
-def make_ipkernel_cmd(mod='ipykernel', executable=None, extra_arguments=None, **kw):
+def make_ipkernel_cmd(mod='ipykernel_launcher', executable=None, extra_arguments=None, **kw):
     """Build Popen command list for launching an IPython kernel.
 
     Parameters
@@ -72,6 +71,12 @@ def write_kernel_spec(path=None, overrides=None, extra_arguments=None):
     
     # stage resources
     shutil.copytree(RESOURCES, path)
+
+    # ensure path is writable
+    mask = os.stat(path).st_mode
+    if not mask & stat.S_IWUSR:
+        os.chmod(path, mask | stat.S_IWUSR)
+
     # write kernel.json
     kernel_dict = get_kernel_dict(extra_arguments)
 
@@ -84,7 +89,7 @@ def write_kernel_spec(path=None, overrides=None, extra_arguments=None):
 
 
 def install(kernel_spec_manager=None, user=False, kernel_name=KERNEL_NAME, display_name=None,
-            prefix=None, profile=None):
+            prefix=None, profile=None, env=None):
     """Install the IPython kernelspec for Jupyter
     
     Parameters
@@ -105,6 +110,10 @@ def install(kernel_spec_manager=None, user=False, kernel_name=KERNEL_NAME, displ
     prefix: str, optional
         Specify an install prefix for the kernelspec.
         This is needed to install into a non-default location, such as a conda/virtual-env.
+    env: dict, optional
+        A dictionary of extra environment variables for the kernel.
+        These will be added to the current environment variables before the
+        kernel is started
 
     Returns
     -------
@@ -128,6 +137,8 @@ def install(kernel_spec_manager=None, user=False, kernel_name=KERNEL_NAME, displ
             overrides["display_name"] = 'Python %i [profile=%s]' % (sys.version_info[0], profile)
     else:
         extra_arguments = None
+    if env:
+        overrides['env'] = env
     path = write_kernel_spec(overrides=overrides, extra_arguments=extra_arguments)
     dest = kernel_spec_manager.install_kernel_spec(
         path, kernel_name=kernel_name, user=user, prefix=prefix)
@@ -170,10 +181,14 @@ class InstallIPythonKernelSpecApp(Application):
         parser.add_argument('--sys-prefix', action='store_const', const=sys.prefix, dest='prefix',
             help="Install to Python's sys.prefix."
             " Shorthand for --prefix='%s'. For use in conda/virtual-envs." % sys.prefix)
+        parser.add_argument('--env', action='append', nargs=2, metavar=('ENV', 'VALUE'),
+            help="Set environment variables for the kernel.")
         opts = parser.parse_args(self.argv)
+        if opts.env:
+            opts.env = {k:v for (k, v) in opts.env}
         try:
             dest = install(user=opts.user, kernel_name=opts.name, profile=opts.profile,
-                           prefix=opts.prefix, display_name=opts.display_name)
+                           prefix=opts.prefix, display_name=opts.display_name, env=opts.env)
         except OSError as e:
             if e.errno == errno.EACCES:
                 print(e, file=sys.stderr)
