@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """A ZMQ-based subclass of InteractiveShell.
 
 This code is meant to ease the refactoring of the base InteractiveShell into
@@ -15,8 +14,6 @@ machinery.  This should thus be thought of as scaffolding.
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from __future__ import print_function
-
 import os
 import sys
 import time
@@ -44,7 +41,6 @@ from IPython.utils import openpy
 from ipykernel.jsonutil import json_clean, encode_images
 from IPython.utils.process import arg_split, system
 from ipython_genutils import py3compat
-from ipython_genutils.py3compat import unicode_type
 from traitlets import (
     Instance, Type, Dict, CBool, CBytes, Any, default, observe
 )
@@ -53,6 +49,13 @@ from ipykernel.displayhook import ZMQShellDisplayHook
 from jupyter_core.paths import jupyter_runtime_dir
 from jupyter_client.session import extract_header, Session
 
+try:
+    # available since ipyparallel 5.0.0
+    from ipyparallel.engine.datapub import ZMQDataPublisher
+except ImportError:
+    # Deprecated since ipykernel 4.3.0
+    from ipykernel.datapub import ZMQDataPublisher
+
 #-----------------------------------------------------------------------------
 # Functions and classes
 #-----------------------------------------------------------------------------
@@ -156,7 +159,7 @@ class ZMQDisplayPublisher(DisplayPublisher):
         content = dict(wait=wait)
         self._flush_streams()
         self.session.send(
-            self.pub_socket, u'clear_output', content,
+            self.pub_socket, 'clear_output', content,
             parent=self.parent_header, ident=self.topic,
         )
 
@@ -442,7 +445,7 @@ class ZMQInteractiveShell(InteractiveShell):
 
     displayhook_class = Type(ZMQShellDisplayHook)
     display_pub_class = Type(ZMQDisplayPublisher)
-    data_pub_class = Type('ipykernel.datapub.ZMQDataPublisher')
+    data_pub_class = Type(ZMQDataPublisher)
     kernel = Any()
     parent_header = Any()
 
@@ -541,9 +544,9 @@ class ZMQInteractiveShell(InteractiveShell):
         sys.stderr.flush()
 
         exc_content = {
-            u'traceback' : stb,
-            u'ename' : unicode_type(etype.__name__),
-            u'evalue' : py3compat.safe_unicode(evalue),
+            'traceback' : stb,
+            'ename' : str(etype.__name__),
+            'evalue' : py3compat.safe_unicode(evalue),
         }
 
         dh = self.displayhook
@@ -553,7 +556,7 @@ class ZMQInteractiveShell(InteractiveShell):
         if dh.topic:
             topic = dh.topic.replace(b'execute_result', b'error')
 
-        exc_msg = dh.session.send(dh.pub_socket, u'error', json_clean(exc_content),
+        exc_msg = dh.session.send(dh.pub_socket, 'error', json_clean(exc_content),
                                   dh.parent_header, ident=topic)
 
         # FIXME - Once we rely on Python 3, the traceback is stored on the
@@ -594,6 +597,15 @@ class ZMQInteractiveShell(InteractiveShell):
         self.register_magics(KernelMagics)
         self.magics_manager.register_alias('ed', 'edit')
 
+    def enable_matplotlib(self, gui=None):
+        gui, backend = super(ZMQInteractiveShell, self).enable_matplotlib(gui)
+
+        from ipykernel.pylab.backend_inline import configure_inline_support
+
+        configure_inline_support(self, backend)
+
+        return gui, backend
+
     def init_virtualenv(self):
         # Overridden not to do virtualenv detection, because it's probably
         # not appropriate in a kernel. To use a kernel in a virtualenv, install
